srbErrors

|  | ## Cheshire3: srbErrors Module

Module srbErrors

Variables | [hide private]
errmsgs |

Variables Details | [hide private]

    ### errmsgs Value:
        {-6027: 'GRIDFTP_BAD_INPUT_URL_ERR',
         -6026: 'GRIDFTP_GFTP_CONN_OUT_OF_RANG_ERR',
         -6025: 'GRIDFTP_NO_FREE_GFTP_CONN_ERR',
         -6024: 'GRIDFTP_NO_USER_CERT_ERR',
         -6023: 'GRIDFTP_NEED_NEW_PROXY_CERTIFICATE',
         -6022: 'GRIDFTP_OPERATION_NOT_SUPPORT',
         -6021: 'GRIDFTP_SIZE_DONE_CB_ERR',
         0: '',
        ...